@@ -19,7 +19,7 @@ import time
 import os
 
 # own imports
-from .__init__ import DATABASES, VERSION
+from .__init__ import VERSION
 from .__init__ import MONTH_AT_PLACE, DAY_AT_PLACE
 from .__init__ import CURRENT_DAY
 
@@ -191,8 +191,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
         dlg.set_website('http://gbirthday.sourceforge.net/')
 
         def close(w, res):
-            if res == gtk.RESPONSE_CANCEL:
-                w.hide()
+            w.hide()
         dlg.connect('response', close)
         dlg.run()
 
@@ -431,12 +430,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
         def preferences_db(widget, db):
             pref_db = self.gtk_get_top_window(_('Database Configuration'))
 
-            db.create_config(pref_db, self.conf)
+            db.create_config(pref_db)
             pref_db.set_modal(True)
             pref_db.show()
 
         vbox = gtk.VBox(False, 10)
-        for db in DATABASES:
+        for db in self.addressbook.supported_databases:
             hbox = gtk.HBox(False, 2)
             vbox.pack_start(hbox, False, False, 3)
 
@@ -472,9 +471,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 
     def save_config(self):
         '''save config in file'''
-        for db in DATABASES:
-            db.update(self.conf)
+        for database in self.addressbook.supported_databases:
+            database.update()
         self.conf.save()
+        self.addressbook.reload()
+        self._reload_set_icon()
 
     def add(self, text):
         '''Show Dialog to add new Person - not yet implemented!'''
@@ -537,7 +538,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
         calendar.show()
 
         combobox = gtk.combo_box_new_text()
-        for db in DATABASES:
+        for db in self.addressbook.supported_databases:
             if db.CAN_SAVE:
                 combobox.append_text(db.TITLE)
         combobox.set_active(0)
@@ -549,13 +550,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 
         def finish_add(uno, combo, name, calendar, window):
             '''save new added person'''
-            for db in DATABASES:
+            for db in self.addressbook.supported_databases:
                 if db.TITLE == combo.get_active_text():
                     calend = list(calendar.get_date())
                     calend[1] += 1
-                    # FIXME: ugly fix for #563405 adding to Lightning
-                    if db.TITLE == 'Thunderbird/Icedove Lightning':
-                        db.ab = self.addressbook
                     db.add(name.get_text(), datetime.date(*calend))
             window.destroy()
 
@@ -586,7 +584,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
         label.show()
 
         db_combo = gtk.combo_box_new_text()
-        for db in DATABASES:
+        for db in self.addressbook.supported_databases:
             db_combo.append_text(db.TITLE)
         db_combo.set_active(0)
         db_combo.show()
@@ -605,7 +603,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
         label.show()
 
         combobox = gtk.combo_box_new_text()
-        for db in DATABASES:
+        for db in self.addressbook.supported_databases:
             if db.CAN_SAVE:
                 combobox.append_text(db.TITLE)
         combobox.set_active(0)
@@ -626,7 +624,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
         def finish_add(uno, combo, name, calend, window):
             '''save new added person'''
             import datetime
-            for db in DATABASES:
+            for db in self.addressbook.supported_databases:
                 if db.TITLE == combo.get_active_text():
                     calend = list(calend.get_date())
                     calend[1] += 1
